@@ -23,10 +23,10 @@ from deejayd.interfaces import DeejaydError,\
                                DeejaydFileList,\
                                DeejaydMediaList, DeejaydDvdInfo
 from deejayd.ui.config import DeejaydConfig
-from deejayd import mediafilters, player, sources, mediadb, database
+from deejayd import mediafilters, player, sources, mediadb, database, plugins
 
 # Exception imports
-import deejayd.sources.webradio
+import deejayd.sources
 import deejayd.mediadb.library
 
 
@@ -62,7 +62,7 @@ def returns_deejaydanswer(answer_class):
                 objanswer = __kw['objanswer']
                 del __kw['objanswer']
             else:
-               objanswer = True
+                objanswer = True
             if objanswer:
                 ans = answer_class()
                 try:
@@ -120,7 +120,7 @@ class DeejaydStaticPlaylist(deejayd.interfaces.DeejaydStaticPlaylist):
             try: medias = self.library.get_all_files(path)
             except deejayd.mediadb.library.NotFoundException:
                 try: medias = self.library.get_file(path)
-                except NotFoundException:
+                except deejayd.mediadb.library.NotFoundException:
                     raise DeejaydError(_('Path %s not found in library') % path)
             for m in medias: ids.append(m["media_id"])
         self.add_songs(ids)
@@ -209,21 +209,30 @@ class DeejaydWebradioList(deejayd.interfaces.DeejaydWebradioList):
         last = length == -1 and len(wrs) or int(first) + int(length)
         return wrs[int(first):last]
 
+    @returns_deejaydanswer(DeejaydKeyValue)
+    def get_available_sources(self):
+        return dict(self.source.get_available_sources())
+
+    @returns_deejaydanswer(DeejaydList)
+    def get_source_categories(self, source_name):
+        return self.source.get_source_categories(source_name)
+
+    @returns_deejaydanswer(DeejaydAnswer)
+    def set_source(self, source_name):
+        self.source.set_source(source_name)
+
+    @returns_deejaydanswer(DeejaydAnswer)
+    def set_source_categorie(self, categorie):
+        self.source.set_source_categorie(categorie)
+
     @returns_deejaydanswer(DeejaydAnswer)
     def add_webradio(self, name, urls):
-        try:
-            self.source.add(urls, name)
-        except sources.webradio.UnsupportedFormatException:
-            raise DeejaydError(_('Webradio URI not supported'))
-        except sources.webradio.UrlNotFoundException:
-            raise DeejaydError(_('Webradio info could not be retrieved'))
+        self.source.add(urls, name)
 
     @returns_deejaydanswer(DeejaydAnswer)
     def delete_webradios(self, wr_ids):
         ids = map(int, wr_ids)
-        try: self.source.delete(ids)
-        except deejayd.sources._base.SourceError, ex:
-            raise DeejaydError(str(ex))
+        self.source.delete(ids)
 
     @returns_deejaydanswer(DeejaydAnswer)
     def clear(self):
@@ -443,8 +452,9 @@ class DeejayDaemonCore(deejayd.interfaces.DeejaydCore):
             config = DeejaydConfig()
 
         self.db = database.init(config)
+        self.plugin_manager = plugins.PluginManager(config)
 
-        self.player = player.init(self.db, config)
+        self.player = player.init(self.db, self.plugin_manager, config)
         self.player.register_dispatcher(self)
 
         self.audio_library,self.video_library, self.watcher = \
@@ -454,7 +464,8 @@ class DeejayDaemonCore(deejayd.interfaces.DeejaydCore):
             self.video_library.register_dispatcher(self)
 
         self.sources = sources.init(self.player, self.db, self.audio_library,
-                                             self.video_library, config)
+                                    self.video_library, self.plugin_manager,
+                                    config)
         self.sources.register_dispatcher(self)
         for source in self.sources.sources_obj.values():
             source.register_dispatcher(self)
@@ -573,7 +584,7 @@ class DeejayDaemonCore(deejayd.interfaces.DeejaydCore):
         av_sources = self.sources.get_available_sources()
         modes = {}
         for s in self.sources.get_all_sources():
-            modes[s] = s in av_sources or 1 and 0
+            modes[s] = s in av_sources
         return modes
 
     @returns_deejaydanswer(DeejaydAnswer)
