@@ -210,7 +210,7 @@ class DatabaseQueries(object):
         joinquery = ""
         for index, key in enumerate(infos_list):
             selectquery += ",i%d.value" % index
-            joinquery += " JOIN media_info i%d ON i%d.id=i.id AND\
+            joinquery += " LEFT OUTER JOIN media_info i%d ON i%d.id=i.id AND\
                 i%d.ikey='%s'" % (index, index, index, key)
         return selectquery, joinquery
 
@@ -219,7 +219,7 @@ class DatabaseQueries(object):
         selectquery, joinquery = self._build_media_query(infos)
         query = "SELECT DISTINCT "+ selectquery +\
             " FROM library l JOIN library_dir d ON d.id=l.directory\
-                           JOIN media_info i ON i.id=l.id"\
+                           LEFT OUTER JOIN media_info i ON i.id=l.id"\
                            + joinquery+\
             " WHERE d.name = %s AND d.lib_type = %s ORDER BY d.name,l.name"
         cursor.execute(query,(dir, type))
@@ -378,7 +378,7 @@ class DatabaseQueries(object):
 
     @query_decorator("none")
     def update_cover(self, cursor, id, mime, new_image):
-        query = "UPDATE cover SET mime_type = %s lmod = %s, image = %s\
+        query = "UPDATE cover SET mime_type = %s, lmod = %s, image = %s\
                 WHERE id=%s"
         cursor.execute(query, (mime, time.time(), new_image, id))
 
@@ -646,17 +646,45 @@ class DatabaseQueries(object):
     #
     @query_decorator("fetchall")
     def get_webradios(self, cursor):
-        cursor.execute("SELECT wid, name, url FROM webradio ORDER BY wid")
+        cursor.execute("SELECT DISTINCT w.id, w.name, e.url\
+            FROM webradio w INNER JOIN webradio_entries e \
+                            ON w.id = e.webradio_id\
+            ORDER BY w.id, e.id")
 
     @query_decorator("none")
-    def add_webradios(self, cursor, values):
-        query = "INSERT INTO webradio(wid,name,url)VALUES(%s,%s,%s)"
-        cursor.executemany(query,values)
+    def add_webradio(self, cursor, name, urls):
+        query = "INSERT INTO webradio(name)VALUES(%s)"
+        cursor.execute(query, (name,))
+        wid = self.connection.get_last_insert_id(cursor)
+
+        query = "INSERT INTO webradio_entries(url, webradio_id)VALUES(%s,%s)"
+        cursor.executemany(query, [(url,wid) for url in urls])
+        self.connection.commit()
+
+    @query_decorator("none")
+    def remove_webradios(self, cursor, wids):
+        wids = [(wid,) for wid in wids]
+        cursor.executemany("DELETE FROM webradio WHERE id = %s" , wids)
+        cursor.executemany("DELETE FROM webradio_entries\
+            WHERE webradio_id = %s", wids)
+        self.connection.commit()
+
+    @query_decorator("none")
+    def remove_url_from_webradio(self, cursor, wid, url_id):
+        cursor.execute("DELETE FROM webradio_entries\
+            WHERE webradio_id = %s AND id = %s", (wid, url_id))
+        self.connection.commit()
+
+    @query_decorator("none")
+    def add_url_for_webradio(self, cursor, wid, url):
+        cursor.execute("INSERT INTO webradio_entries (url, webradio_id)\
+            VALUES(%s,%s)", (url, wid))
         self.connection.commit()
 
     @query_decorator("none")
     def clear_webradios(self, cursor):
         cursor.execute("DELETE FROM webradio")
+        cursor.execute("DELETE FROM webradio_entries")
         self.connection.commit()
 
     #
@@ -671,15 +699,18 @@ class DatabaseQueries(object):
     #
     @query_decorator("none")
     def set_state(self, cursor, values):
-        cursor.executemany("UPDATE variables SET value = %s WHERE name = %s" \
-            ,values)
+        cursor.executemany("REPLACE INTO variables (value,name)VALUES(%s,%s)",\
+                           values)
         self.connection.commit()
 
     @query_decorator("custom")
     def get_state(self, cursor, type):
         cursor.execute("SELECT value FROM variables WHERE name = %s",(type,))
-        (rs,) =  cursor.fetchone()
-        return rs
+        try:
+            (rs,) =  cursor.fetchone()
+            return rs
+        except (ValueError, TypeError):
+            return None
 
     def close(self):
         self.connection.close()
