@@ -1,5 +1,5 @@
 # Deejayd, a media player daemon
-# Copyright (C) 2007-2008 Mickael Royer <mickael.royer@gmail.com>
+# Copyright (C) 2007-2009 Mickael Royer <mickael.royer@gmail.com>
 #                         Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-def upgrade(cursor):
+def upgrade(cursor, backend, config):
     sql = [
         "INSERT INTO variables VALUES('qrandom','0');",
         "UPDATE variables SET value = '7' WHERE name = 'database_version';",
