@@ -1,5 +1,5 @@
 # Deejayd, a media player daemon
-# Copyright (C) 2007-2008 Mickael Royer <mickael.royer@gmail.com>
+# Copyright (C) 2007-2009 Mickael Royer <mickael.royer@gmail.com>
 #                         Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,31 +18,19 @@
 
 import os, glob
 
-def get_audio_extensions(player):
-    base = os.path.dirname(__file__)
-    base_import = "deejayd.mediadb.formats"
+def get_extensions(player, type = "audio"):
+    base = os.path.join(os.path.dirname(__file__), type)
+    base_import = "deejayd.mediadb.formats.%s" % type
     ext_dict = {}
 
     modules = [os.path.basename(f[:-3]) \
-                for f in glob.glob(os.path.join(base, "[!_]*.py"))\
-                if os.path.basename(f).startswith("audio")]
+                for f in glob.glob(os.path.join(base, "[!_]*.py"))]
     for m in modules:
         mod = __import__(base_import+"."+m, {}, {}, base)
-        inst = mod.object()
+        filetype_class = mod.object
         for ext in mod.extensions:
             if player.is_supported_format(ext):
-                ext_dict[ext] = inst
-
-    return ext_dict
-
-def get_video_extensions(player):
-    ext_dict = {}
-
-    from deejayd.mediadb.formats import video
-    inst = video.object(player)
-    for ext in video.extensions:
-            if player.is_supported_format(ext):
-                ext_dict[ext] = inst
+                ext_dict[ext] = filetype_class
 
     return ext_dict
 
