@@ -19,7 +19,10 @@
 import os,subprocess
 
 from deejayd.component import SignalingComponent
+from deejayd.plugins import PluginError, IPlayerPlugin
 from deejayd.player import PlayerError
+from deejayd.ui import log
+from deejayd.utils import get_uris_from_pls, get_uris_from_m3u
 
 PLAYER_PLAY = "play"
 PLAYER_PAUSE = "pause"
@@ -27,10 +30,17 @@ PLAYER_STOP = "stop"
 
 class UnknownPlayer(SignalingComponent):
 
-    def __init__(self, db, config):
+    def __init__(self, db, plugin_manager, config):
         SignalingComponent.__init__(self)
         self.config = config
         self.db = db
+        # Init plugins
+        self.plugins = []
+        plugins_cls = plugin_manager.get_plugins(IPlayerPlugin)
+        for plugin in plugins_cls:
+            try: self.plugins.append(plugin(config))
+            except PluginError, err:
+                log.err(_("Unable to init %s plugin: %s")%(plugin.NAME, err))
 
         # Initialise var
         self._video_support = False
@@ -38,6 +48,7 @@ class UnknownPlayer(SignalingComponent):
         self._media_file = None
         self._replaygain = config.getboolean("general","replaygain")
 
+
     def load_state(self):
         # Restore volume
         self.set_volume(float(self.db.get_state("volume")))
@@ -57,7 +68,7 @@ class UnknownPlayer(SignalingComponent):
                 self.stop()
             else:
                 if self._media_file and self._media_file["source"] != "queue":
-                   self.set_position(int(self.db.get_state("current_pos")))
+                    self.set_position(int(self.db.get_state("current_pos")))
         if state == PLAYER_PAUSE:
             self.pause()
 
@@ -75,6 +86,24 @@ class UnknownPlayer(SignalingComponent):
         elif self.get_state() in (PLAYER_PAUSE, PLAYER_PLAY):
             self.pause()
 
+    def start_play(self):
+        if not self._media_file: return
+        if self._media_file["type"] == "webradio":
+            if self._media_file["url-type"] == "pls":
+                try:
+                    urls = get_uris_from_pls(self._media_file["url"])
+                except IOError:
+                    raise PlayerError(_("Unable to get pls for webradio %s")\
+                                      % self._media_file["title"])
+                if not len(urls): # we don't succeed to extract uri
+                    raise PlayerError(\
+                            _("Unable to extract uri from pls playlist"))
+                self._media_file.update({"urls": urls, "url-index": 0, \
+                                         "url-type": "urls"})
+            idx = self._media_file["url-index"]
+            self._media_file["uri"] = \
+                    self._media_file["urls"][idx].encode("utf-8")
+
     def pause(self):
         raise NotImplementedError
 
@@ -206,6 +235,11 @@ class UnknownPlayer(SignalingComponent):
         return status
 
     def close(self):
+        # close plugins
+        for plugin in self.plugins:
+            plugin.close()
+
+        # save state
         current = self._media_file or {"pos": "-1", "source": "none"}
         states = [
             (str(self.get_volume()), "volume"),
