@@ -16,7 +16,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-import os, subprocess
+import os
 from os import path
 import kaa.metadata
 from twisted.internet import reactor
@@ -30,10 +30,10 @@ from deejayd.ui import log
 class XinePlayer(UnknownPlayer):
     name = "xine"
     supported_extensions = None
-    plugins = None
+    xine_plugins = None
 
-    def __init__(self,db,config):
-        UnknownPlayer.__init__(self,db,config)
+    def __init__(self, db, plugin_manager, config):
+        UnknownPlayer.__init__(self, db, plugin_manager, config)
         self.__xine_options = {
             "video": self.config.get("xine", "video_output"),
             "display" : self.config.get("xine", "video_display"),
@@ -67,6 +67,7 @@ class XinePlayer(UnknownPlayer):
         self.__osd = None
 
     def start_play(self):
+        super(XinePlayer, self).start_play()
         if not self._media_file: return
 
         # format correctly the uri
@@ -111,14 +112,35 @@ class XinePlayer(UnknownPlayer):
         if stream_should_change:
             self._create_stream(needs_video)
 
-        try:
-            self.__stream.open(uri)
-            self.__stream.play(0, 0)
-        except xine.XineError:
-            self._destroy_stream()
-            msg = _("Unable to play file %s") % uri
-            log.err(msg)
-            raise PlayerError(msg)
+        def open_uri(uri):
+            try:
+                self.__stream.open(uri)
+                self.__stream.play(0, 0)
+            except xine.XineError:
+                msg = _("Unable to play file %s") % uri
+                log.err(msg)
+                raise PlayerError(msg)
+
+        if self._media_file["type"] == "webradio":
+            while True:
+                try: open_uri(self._media_file["uri"])
+                except PlayerError, ex:
+                    if self._media_file["url-index"] < \
+                                            len(self._media_file["urls"])-1:
+                        self._media_file["url-index"] += 1
+                        self._media_file["uri"] = \
+                                self._media_file["urls"]\
+                                [self._media_file["url-index"]].encode("utf-8")
+                    else:
+                        raise ex
+                else:
+                    break
+        else:
+            try: open_uri(uri)
+            except PlayerError, ex:
+                self._destroy_stream()
+                raise ex
+
         if self.__window:
             self.__window.show(self.current_is_video())
 
@@ -129,10 +151,16 @@ class XinePlayer(UnknownPlayer):
             if "audio" in self._media_file:
                 self._media_file["audio_idx"] = self.__stream.get_param(\
                         xine.Stream.XINE_PARAM_AUDIO_CHANNEL_LOGICAL)
+            else:
+                self._player_set_alang(-1) # auto audio channel
             if "subtitle" in self._media_file:
                 self._media_file["sub_offset"] = 0
                 self._media_file["subtitle_idx"] = self.__stream.get_param(\
                         xine.Stream.XINE_PARAM_SPU_CHANNEL)
+            else:
+                self._player_set_slang(-1) # auto subtitle channel
+                try: del self._media_file["sub_offset"]
+                except KeyError: pass
             # set video aspect ration to default value
             self.set_aspectratio(self.__default_aspect_ratio)
 
@@ -272,10 +300,10 @@ class XinePlayer(UnknownPlayer):
         return PLAYER_STOP
 
     def is_supported_uri(self,uri_type):
-        if self.plugins == None:
-            self.plugins = self.__xine.list_input_plugins()
+        if self.xine_plugins == None:
+            self.xine_plugins = self.__xine.list_input_plugins()
 
-        return uri_type in self.plugins
+        return uri_type in self.xine_plugins
 
     def is_supported_format(self,format):
         if self.supported_extensions == None:
@@ -356,8 +384,21 @@ class XinePlayer(UnknownPlayer):
     #
     def _eof(self):
         if self._media_file:
-            try: self._media_file.played()
-            except AttributeError: pass
+            if self._media_file["type"] == "webradio":
+                # an error happened, try the next url
+                if self._media_file["url-index"] \
+                        < len(self._media_file["urls"])-1:
+                    self._media_file["url-index"] += 1
+                    self._media_file["uri"] = \
+                            self._media_file["urls"]\
+                                [self._media_file["url-index"]].encode("utf-8")
+                    self.start_play()
+                return False
+            else:
+                try: self._media_file.played()
+                except AttributeError: pass
+                for plugin in self.plugins:
+                    plugin.on_media_played(self._media_file)
         new_file = self._source.next(explicit = False)
         try: self._change_file(new_file, gapless = True)
         except PlayerError:
@@ -398,15 +439,11 @@ class XinePlayer(UnknownPlayer):
             reactor.callFromThread(self._update_metadata)
         elif event.type == xine.Event.XINE_EVENT_UI_MESSAGE:
             log.info("Xine event : message")
-            msg = event.data.contents
-            if msg.type != xine.XinePlayer.XINE_MSG_NO_ERROR:
-                if msg.explanation:
-                    # FIXME : This is strange to use pointer arithemtics here,
-                    # as ctypes may automatically dereference pointers, I think
-                    # msg.explanation should suffice...
-                    message = string_at(addressof(msg) + msg.explanation)
-                else:
-                    message = _("Xine error %s") % msg.type
+            try:
+                message = event.message()
+            except xine.XineError, errornum:
+                message = _("Xine error %s") % errornum
+            if message is not None:
                 reactor.callFromThread(log.err, message)
         return True
 
