@@ -1,5 +1,5 @@
 # Deejayd, a media player daemon
-# Copyright (C) 2007-2008 Mickael Royer <mickael.royer@gmail.com>
+# Copyright (C) 2007-2009 Mickael Royer <mickael.royer@gmail.com>
 #                         Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -26,8 +26,12 @@ class DeejaydTranslations(gettext.GNUTranslations):
         self.plural = lambda n: n > 1
         gettext.GNUTranslations.__init__(self, *args, **kwargs)
 
-    def install(self):
-        __builtin__.__dict__["_"] = self.gettext
-        __builtin__.__dict__["ngettext"] = self.ngettext
+    def install(self, unicode = True):
+        if unicode:
+            __builtin__.__dict__["_"] = self.ugettext
+            __builtin__.__dict__["ngettext"] = self.ungettext
+        else:
+            __builtin__.__dict__["_"] = self.gettext
+            __builtin__.__dict__["ngettext"] = self.ngettext
 
 # vim: ts=4 sw=4 expandtab
