@@ -50,7 +50,7 @@ class InterfaceTests:
         ans = self.deejayd.get_mode()
         for k in known_keys:
             self.failUnless(k in ans.get_contents().keys())
-            self.failUnless(int(ans[k]) in (0,1))
+            self.failUnless(ans[k] in (True, False))
 
     def testGetStats(self):
         """Test getStats command"""
@@ -187,31 +187,32 @@ class InterfaceTests:
 
         wr_list = self.deejayd.get_webradios()
 
+        # try to set wrong source
+        ans = wr_list.set_source(self.testdata.getRandomString())
+        self.assertRaises(DeejaydError, ans.get_contents)
+        # set local source
+        ans = wr_list.set_source('local')
+        self.failUnless(ans.get_contents())
+        # local does not have categorie, raise DeejaydError if we try to get it
+        ans = wr_list.get_source_categories('local')
+        self.assertRaises(DeejaydError, ans.get_contents)
+
+
         # Test for bad URI and inexistant playlist
-        for badURI in [[self.testdata.getRandomString(50)],]:
-                   #['http://' + self.testdata.getRandomString(50) + '.pls']]:
-            ans = wr_list.add_webradio(self.testdata.getRandomString(),
-                                       badURI[0])
-            # FIXME : provision for the future where the same webradio may have
-            # multiple urls.
-            #                          badURI)
+        for badURI in [[self.testdata.getRandomString(50)],\
+                   ['http://' + self.testdata.getRandomString(50) + '.pls']]:
+            ans = wr_list.add_webradio(self.testdata.getRandomString(), badURI)
             self.assertRaises(DeejaydError, ans.get_contents)
 
         testWrName = self.testdata.getRandomString()
 
-        # FIXME : provision for the future where the same webradio may have
-        # multiple urls.
-        # testWrUrls = []
-        # for urlCount in range(self.testdata.getRandomInt(10)):
-        #     testWrUrls.append('http://' + self.testdata.getRandomString(50))
-        testWrUrls = 'http://' + self.testdata.getRandomString(50)
+        testWrUrls = []
+        for urlCount in range(self.testdata.getRandomInt(10)):
+            testWrUrls.append('http://' + self.testdata.getRandomString(50))
 
         ans = wr_list.add_webradio(testWrName, testWrUrls)
         self.failUnless(ans.get_contents())
 
-        # FIXME : This should not be, see the future of webradios.
-        testWrName += '-1'
-
         wr_list = self.deejayd.get_webradios()
         wr_names = [wr['title'] for wr in wr_list.get().get_medias()]
         self.failUnless(testWrName in wr_names)
@@ -219,10 +220,8 @@ class InterfaceTests:
         retrievedWr = [wr for wr in wr_list.get().get_medias()\
                           if wr['title'] == testWrName][0]
 
-        # FIXME : Same provision for the future.
-        # for url in testWrUrls:
-        #     self.failUnless(url in retrievedWr['Url'])
-        self.assertEqual(testWrUrls, retrievedWr['url'])
+        for url in testWrUrls:
+            self.failUnless(url in retrievedWr['urls'])
 
         ans = wr_list.delete_webradio(51)
         self.assertRaises(DeejaydError, ans.get_contents)
@@ -469,7 +468,7 @@ class InterfaceTests:
         opt = self.testdata.getRandomString()
         ans = self.deejayd.set_option("playlist", opt, 1)
         self.assertRaises(DeejaydError, ans.get_contents)
-        ans = self.deejayd.set_option(opt, "repeat", 1)
+        ans = self.deejayd.set_option(opt, "repeat", True)
         self.assertRaises(DeejaydError, ans.get_contents)
 
         ans = self.deejayd.set_option("webradio", "playorder", "inorder")
@@ -482,10 +481,10 @@ class InterfaceTests:
         self.assertEqual(status["playlistplayorder"], "random")
         # set video option
         if self.video_support:
-            ans = self.deejayd.set_option("video", "repeat", "1")
+            ans = self.deejayd.set_option("video", "repeat", True)
             ans.get_contents()
             status = self.deejayd.get_status().get_contents()
-            self.assertEqual(status["videorepeat"], 1)
+            self.assertEqual(status["videorepeat"], True)
 
     def testAudioPlayer(self):
         """ Test player commands (play, pause,...) for audio """
